/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef AccessType_enum_table_h_automatic
#define AccessType_enum_table_h_automatic

typedef enum RabbitizerAccessType {
RAB_ACCESSTYPE_INVALID,
RAB_ACCESSTYPE_BYTE,
RAB_ACCESSTYPE_SHORT,
RAB_ACCESSTYPE_WORD,
RAB_ACCESSTYPE_DOUBLEWORD,
RAB_ACCESSTYPE_FLOAT,
RAB_ACCESSTYPE_DOUBLEFLOAT,
    RAB_ACCESSTYPE_MAX,
} RabbitizerAccessType;

#endif
