/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        COP1_CONTROL,      0,  0,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      1,  1,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      2,  2,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      3,  3,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      4,  4,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      5,  5,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      6,  6,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      7,  7,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      8,  8,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,      9,  9,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL,     30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_CONTROL, FpcCsr, 31,
        0
    )
