/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef Abi_enum_table_h_automatic
#define Abi_enum_table_h_automatic

typedef enum RabbitizerAbi {
RABBITIZER_ABI_NUMERIC,
RABBITIZER_ABI_O32,
RABBITIZER_ABI_N32,
RABBITIZER_ABI_N64,
    RABBITIZER_ABI_MAX,
} RabbitizerAbi;

#endif
