/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef InstrCategory_Names_array_table_h_automatic
#define InstrCategory_Names_array_table_h_automatic

const char *const RabbitizerInstrCategory_Names[] = {
[RABBITIZER_INSTRCAT_CPU] = "CPU",
[RABBITIZER_INSTRCAT_RSP] = "RSP",
[RABBITIZER_INSTRCAT_R5900] = "R5900",
};

#endif
