/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        COP1_N32, fv0,   f0,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft14,  f1,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fv1,   f2,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft15,  f3,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft0,   f4,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft1,   f5,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft2,   f6,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft3,   f7,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft4,   f8,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft5,   f9,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft6,  f10,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft7,  f11,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa0,  f12,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa1,  f13,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa2,  f14,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa3,  f15,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa4,  f16,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa5,  f17,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa6,  f18,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fa7,  f19,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs0,  f20,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft8,  f21,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs1,  f22,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft9,  f23,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs2,  f24,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft10, f25,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs3,  f26,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft11, f27,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs4,  f28,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft12, f29,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, fs5,  f30,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_N32, ft13, f31,
        0
    )
