/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        R5900_VF,  vf0,  0,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf1,  1,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf2,  2,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf3,  3,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf4,  4,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf5,  5,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf6,  6,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf7,  7,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf8,  8,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF,  vf9,  9,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VF, vf31, 31,
        0
    )
