/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

#include "common/RabbitizerVersion.h"

const int RabVersion_Major = RAB_VERSION_MAJOR;
const int RabVersion_Minor = RAB_VERSION_MINOR;
const int RabVersion_Patch = RAB_VERSION_PATCH;

const char RabVersion_Str[] = RAB_VERSION_STR;
