/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_MEM_ADDR,   0,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_DRAM_ADDR,  1,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_RD_LEN,     2,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_WR_LEN,     3,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_STATUS,     4,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_DMA_FULL,   5,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_DMA_BUSY,   6,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, SP_SEMAPHORE,  7,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_START,     8,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_END,       9,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_CURRENT,  10,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_STATUS,   11,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_CLOCK,    12,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_BUFBUSY,  13,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_PIPEBUSY, 14,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        RSP_COP0, DPC_TMEM,     15,
        0
    )
