/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        R5900_VI,  vi0,  0,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi1,  1,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi2,  2,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi3,  3,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi4,  4,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi5,  5,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi6,  6,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi7,  7,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi8,  8,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI,  vi9,  9,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        R5900_VI, vi31, 31,
        0
    )
