/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        RSP_GPR, zero,  0,
        .isZero=true
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    1,  1,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    2,  2,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    3,  3,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    4,  4,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    5,  5,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    6,  6,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    7,  7,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    8,  8,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,    9,  9,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_GPR,   ra, 31,
        .isClobberedByFuncCall=true,
        .isRa=true
    )
