/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

RAB_DEF_ACCESSTYPE(INVALID)

RAB_DEF_ACCESSTYPE(BYTE)
RAB_DEF_ACCESSTYPE(SHORT)
RAB_DEF_ACCESSTYPE(WORD)
RAB_DEF_ACCESSTYPE(DOUBLEWORD)
RAB_DEF_ACCESSTYPE(FLOAT)
RAB_DEF_ACCESSTYPE(DOUBLEFLOAT)
