/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        COP2,  0,  0,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  1,  1,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  2,  2,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  3,  3,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  4,  4,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  5,  5,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  6,  6,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  7,  7,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  8,  8,
        0
    )
    RABBITIZER_DEF_REG(
        COP2,  9,  9,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        COP2, 31, 31,
        0
    )
