#!/usr/bin/env python3

# SPDX-FileCopyrightText: © 2022 Decompollaborate
# SPDX-License-Identifier: MIT

from __future__ import annotations


class Utils:
    @staticmethod
    def from2Complement(number: int, bits: int) -> int: ...

    @staticmethod
    def escapeString(src: str) -> str: ...
