/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        COP1_O32, fv0,   f0,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fv0f,  f1,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fv1,   f2,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fv1f,  f3,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft0,   f4,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft0f,  f5,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft1,   f6,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft1f,  f7,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft2,   f8,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft2f,  f9,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft3,  f10,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft3f, f11,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fa0,  f12,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fa0f, f13,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fa1,  f14,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fa1f, f15,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft4,  f16,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft4f, f17,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft5,  f18,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, ft5f, f19,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs0,  f20,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs0f, f21,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs1,  f22,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs1f, f23,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs2,  f24,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs2f, f25,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs3,  f26,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs3f, f27,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs4,  f28,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs4f, f29,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs5,  f30,
        0
    )
    RABBITIZER_DEF_REG(
        COP1_O32, fs5f, f31,
        0
    )
