/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef RegisterDescriptor_Descriptors_arrays_table_h_automatic
#define RegisterDescriptor_Descriptors_arrays_table_h_automatic

const RabbitizerRegisterDescriptor RabbitizerRegister_GprO32_Descriptors[] = {
    [RABBITIZER_REG_GPR_O32_zero] = { .isZero=true },
    [RABBITIZER_REG_GPR_O32_at] = { .isClobberedByFuncCall=true, .isAt=true },
    [RABBITIZER_REG_GPR_O32_v0] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_O32_v1] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_O32_a0] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a1] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a2] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_a3] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_O32_t0] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t1] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t2] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t3] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t4] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t5] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t6] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t7] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_s0] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s1] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s2] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s3] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s4] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s5] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s6] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_s7] = { .isSaved=true },
    [RABBITIZER_REG_GPR_O32_t8] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_t9] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_O32_k0] = { .isKernel=true },
    [RABBITIZER_REG_GPR_O32_k1] = { .isKernel=true },
    [RABBITIZER_REG_GPR_O32_gp] = { .isGp=true },
    [RABBITIZER_REG_GPR_O32_sp] = { .isStackPointer=true },
    [RABBITIZER_REG_GPR_O32_fp] = { 0 },
    [RABBITIZER_REG_GPR_O32_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_GprN32_Descriptors[] = {
    [RABBITIZER_REG_GPR_N32_zero] = { .isZero=true },
    [RABBITIZER_REG_GPR_N32_at] = { .isClobberedByFuncCall=true, .isAt=true },
    [RABBITIZER_REG_GPR_N32_v0] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_N32_v1] = { .isClobberedByFuncCall=true, .isReturnReg=true },
    [RABBITIZER_REG_GPR_N32_a0] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a1] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a2] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a3] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a4] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a5] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a6] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_a7] = { .isClobberedByFuncCall=true, .isArg=true },
    [RABBITIZER_REG_GPR_N32_t0] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t1] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t2] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t3] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_s0] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s1] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s2] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s3] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s4] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s5] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s6] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_s7] = { .isSaved=true },
    [RABBITIZER_REG_GPR_N32_t8] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_t9] = { .isClobberedByFuncCall=true, .isTemp=true },
    [RABBITIZER_REG_GPR_N32_k0] = { .isKernel=true },
    [RABBITIZER_REG_GPR_N32_k1] = { .isKernel=true },
    [RABBITIZER_REG_GPR_N32_gp] = { .isGp=true },
    [RABBITIZER_REG_GPR_N32_sp] = { .isStackPointer=true },
    [RABBITIZER_REG_GPR_N32_fp] = { 0 },
    [RABBITIZER_REG_GPR_N32_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop0_Descriptors[] = {
    [RABBITIZER_REG_COP0_Index] = { 0 },
    [RABBITIZER_REG_COP0_Random] = { 0 },
    [RABBITIZER_REG_COP0_EntryLo0] = { 0 },
    [RABBITIZER_REG_COP0_EntryLo1] = { 0 },
    [RABBITIZER_REG_COP0_Context] = { 0 },
    [RABBITIZER_REG_COP0_PageMask] = { 0 },
    [RABBITIZER_REG_COP0_Wired] = { 0 },
    [RABBITIZER_REG_COP0_Reserved07] = { .isReserved=true },
    [RABBITIZER_REG_COP0_BadVaddr] = { 0 },
    [RABBITIZER_REG_COP0_Count] = { 0 },
    [RABBITIZER_REG_COP0_EntryHi] = { 0 },
    [RABBITIZER_REG_COP0_Compare] = { 0 },
    [RABBITIZER_REG_COP0_Status] = { 0 },
    [RABBITIZER_REG_COP0_Cause] = { 0 },
    [RABBITIZER_REG_COP0_EPC] = { 0 },
    [RABBITIZER_REG_COP0_PRevID] = { 0 },
    [RABBITIZER_REG_COP0_Config] = { 0 },
    [RABBITIZER_REG_COP0_LLAddr] = { 0 },
    [RABBITIZER_REG_COP0_WatchLo] = { 0 },
    [RABBITIZER_REG_COP0_WatchHi] = { 0 },
    [RABBITIZER_REG_COP0_XContext] = { 0 },
    [RABBITIZER_REG_COP0_Reserved21] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved22] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved23] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved24] = { .isReserved=true },
    [RABBITIZER_REG_COP0_Reserved25] = { .isReserved=true },
    [RABBITIZER_REG_COP0_PErr] = { 0 },
    [RABBITIZER_REG_COP0_CacheErr] = { 0 },
    [RABBITIZER_REG_COP0_TagLo] = { 0 },
    [RABBITIZER_REG_COP0_TagHi] = { 0 },
    [RABBITIZER_REG_COP0_ErrorEPC] = { 0 },
    [RABBITIZER_REG_COP0_Reserved31] = { .isReserved=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1O32_Descriptors[] = {
    [RABBITIZER_REG_COP1_O32_fv0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fv1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft0] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft1] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft2] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft2f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft3] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft3f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fa1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft4] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft4f] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft5] = { 0 },
    [RABBITIZER_REG_COP1_O32_ft5f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs0] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs0f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs1] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs1f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs2] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs2f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs3] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs3f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs4] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs4f] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs5] = { 0 },
    [RABBITIZER_REG_COP1_O32_fs5f] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1N32_Descriptors[] = {
    [RABBITIZER_REG_COP1_N32_fv0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft14] = { 0 },
    [RABBITIZER_REG_COP1_N32_fv1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft15] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft2] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft3] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft4] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft5] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft6] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft7] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa0] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa1] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa2] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa3] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa4] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa5] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa6] = { 0 },
    [RABBITIZER_REG_COP1_N32_fa7] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs0] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft8] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs1] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft9] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs2] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft10] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs3] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft11] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs4] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft12] = { 0 },
    [RABBITIZER_REG_COP1_N32_fs5] = { 0 },
    [RABBITIZER_REG_COP1_N32_ft13] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1N64_Descriptors[] = {
    [RABBITIZER_REG_COP1_N64_fv0] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft12] = { 0 },
    [RABBITIZER_REG_COP1_N64_fv1] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft13] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft0] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft1] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft2] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft3] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft4] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft5] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft6] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft7] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa0] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa1] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa2] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa3] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa4] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa5] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa6] = { 0 },
    [RABBITIZER_REG_COP1_N64_fa7] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft8] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft9] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft10] = { 0 },
    [RABBITIZER_REG_COP1_N64_ft11] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs0] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs1] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs2] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs3] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs4] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs5] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs6] = { 0 },
    [RABBITIZER_REG_COP1_N64_fs7] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop1Control_Descriptors[] = {
    [RABBITIZER_REG_COP1_CONTROL_0] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_1] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_2] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_3] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_4] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_5] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_6] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_7] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_8] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_9] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_10] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_11] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_12] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_13] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_14] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_15] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_16] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_17] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_18] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_19] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_20] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_21] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_22] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_23] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_24] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_25] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_26] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_27] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_28] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_29] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_30] = { 0 },
    [RABBITIZER_REG_COP1_CONTROL_FpcCsr] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_Cop2_Descriptors[] = {
    [RABBITIZER_REG_COP2_0] = { 0 },
    [RABBITIZER_REG_COP2_1] = { 0 },
    [RABBITIZER_REG_COP2_2] = { 0 },
    [RABBITIZER_REG_COP2_3] = { 0 },
    [RABBITIZER_REG_COP2_4] = { 0 },
    [RABBITIZER_REG_COP2_5] = { 0 },
    [RABBITIZER_REG_COP2_6] = { 0 },
    [RABBITIZER_REG_COP2_7] = { 0 },
    [RABBITIZER_REG_COP2_8] = { 0 },
    [RABBITIZER_REG_COP2_9] = { 0 },
    [RABBITIZER_REG_COP2_10] = { 0 },
    [RABBITIZER_REG_COP2_11] = { 0 },
    [RABBITIZER_REG_COP2_12] = { 0 },
    [RABBITIZER_REG_COP2_13] = { 0 },
    [RABBITIZER_REG_COP2_14] = { 0 },
    [RABBITIZER_REG_COP2_15] = { 0 },
    [RABBITIZER_REG_COP2_16] = { 0 },
    [RABBITIZER_REG_COP2_17] = { 0 },
    [RABBITIZER_REG_COP2_18] = { 0 },
    [RABBITIZER_REG_COP2_19] = { 0 },
    [RABBITIZER_REG_COP2_20] = { 0 },
    [RABBITIZER_REG_COP2_21] = { 0 },
    [RABBITIZER_REG_COP2_22] = { 0 },
    [RABBITIZER_REG_COP2_23] = { 0 },
    [RABBITIZER_REG_COP2_24] = { 0 },
    [RABBITIZER_REG_COP2_25] = { 0 },
    [RABBITIZER_REG_COP2_26] = { 0 },
    [RABBITIZER_REG_COP2_27] = { 0 },
    [RABBITIZER_REG_COP2_28] = { 0 },
    [RABBITIZER_REG_COP2_29] = { 0 },
    [RABBITIZER_REG_COP2_30] = { 0 },
    [RABBITIZER_REG_COP2_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspGpr_Descriptors[] = {
    [RABBITIZER_REG_RSP_GPR_zero] = { .isZero=true },
    [RABBITIZER_REG_RSP_GPR_1] = { 0 },
    [RABBITIZER_REG_RSP_GPR_2] = { 0 },
    [RABBITIZER_REG_RSP_GPR_3] = { 0 },
    [RABBITIZER_REG_RSP_GPR_4] = { 0 },
    [RABBITIZER_REG_RSP_GPR_5] = { 0 },
    [RABBITIZER_REG_RSP_GPR_6] = { 0 },
    [RABBITIZER_REG_RSP_GPR_7] = { 0 },
    [RABBITIZER_REG_RSP_GPR_8] = { 0 },
    [RABBITIZER_REG_RSP_GPR_9] = { 0 },
    [RABBITIZER_REG_RSP_GPR_10] = { 0 },
    [RABBITIZER_REG_RSP_GPR_11] = { 0 },
    [RABBITIZER_REG_RSP_GPR_12] = { 0 },
    [RABBITIZER_REG_RSP_GPR_13] = { 0 },
    [RABBITIZER_REG_RSP_GPR_14] = { 0 },
    [RABBITIZER_REG_RSP_GPR_15] = { 0 },
    [RABBITIZER_REG_RSP_GPR_16] = { 0 },
    [RABBITIZER_REG_RSP_GPR_17] = { 0 },
    [RABBITIZER_REG_RSP_GPR_18] = { 0 },
    [RABBITIZER_REG_RSP_GPR_19] = { 0 },
    [RABBITIZER_REG_RSP_GPR_20] = { 0 },
    [RABBITIZER_REG_RSP_GPR_21] = { 0 },
    [RABBITIZER_REG_RSP_GPR_22] = { 0 },
    [RABBITIZER_REG_RSP_GPR_23] = { 0 },
    [RABBITIZER_REG_RSP_GPR_24] = { 0 },
    [RABBITIZER_REG_RSP_GPR_25] = { 0 },
    [RABBITIZER_REG_RSP_GPR_26] = { 0 },
    [RABBITIZER_REG_RSP_GPR_27] = { 0 },
    [RABBITIZER_REG_RSP_GPR_28] = { 0 },
    [RABBITIZER_REG_RSP_GPR_29] = { 0 },
    [RABBITIZER_REG_RSP_GPR_30] = { 0 },
    [RABBITIZER_REG_RSP_GPR_ra] = { .isClobberedByFuncCall=true, .isRa=true },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop0_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP0_SP_MEM_ADDR] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DRAM_ADDR] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_RD_LEN] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_WR_LEN] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_STATUS] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DMA_FULL] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_DMA_BUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_SP_SEMAPHORE] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_START] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_END] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_CURRENT] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_STATUS] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_CLOCK] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_BUFBUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_PIPEBUSY] = { 0 },
    [RABBITIZER_REG_RSP_COP0_DPC_TMEM] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop2_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP2_0] = { 0 },
    [RABBITIZER_REG_RSP_COP2_1] = { 0 },
    [RABBITIZER_REG_RSP_COP2_2] = { 0 },
    [RABBITIZER_REG_RSP_COP2_3] = { 0 },
    [RABBITIZER_REG_RSP_COP2_4] = { 0 },
    [RABBITIZER_REG_RSP_COP2_5] = { 0 },
    [RABBITIZER_REG_RSP_COP2_6] = { 0 },
    [RABBITIZER_REG_RSP_COP2_7] = { 0 },
    [RABBITIZER_REG_RSP_COP2_8] = { 0 },
    [RABBITIZER_REG_RSP_COP2_9] = { 0 },
    [RABBITIZER_REG_RSP_COP2_10] = { 0 },
    [RABBITIZER_REG_RSP_COP2_11] = { 0 },
    [RABBITIZER_REG_RSP_COP2_12] = { 0 },
    [RABBITIZER_REG_RSP_COP2_13] = { 0 },
    [RABBITIZER_REG_RSP_COP2_14] = { 0 },
    [RABBITIZER_REG_RSP_COP2_15] = { 0 },
    [RABBITIZER_REG_RSP_COP2_16] = { 0 },
    [RABBITIZER_REG_RSP_COP2_17] = { 0 },
    [RABBITIZER_REG_RSP_COP2_18] = { 0 },
    [RABBITIZER_REG_RSP_COP2_19] = { 0 },
    [RABBITIZER_REG_RSP_COP2_20] = { 0 },
    [RABBITIZER_REG_RSP_COP2_21] = { 0 },
    [RABBITIZER_REG_RSP_COP2_22] = { 0 },
    [RABBITIZER_REG_RSP_COP2_23] = { 0 },
    [RABBITIZER_REG_RSP_COP2_24] = { 0 },
    [RABBITIZER_REG_RSP_COP2_25] = { 0 },
    [RABBITIZER_REG_RSP_COP2_26] = { 0 },
    [RABBITIZER_REG_RSP_COP2_27] = { 0 },
    [RABBITIZER_REG_RSP_COP2_28] = { 0 },
    [RABBITIZER_REG_RSP_COP2_29] = { 0 },
    [RABBITIZER_REG_RSP_COP2_30] = { 0 },
    [RABBITIZER_REG_RSP_COP2_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspCop2Control_Descriptors[] = {
    [RABBITIZER_REG_RSP_COP2_CONTROL_0] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_1] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_2] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_3] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_4] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_5] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_6] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_7] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_8] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_9] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_10] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_11] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_12] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_13] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_14] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_15] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_16] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_17] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_18] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_19] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_20] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_21] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_22] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_23] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_24] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_25] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_26] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_27] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_28] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_29] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_30] = { 0 },
    [RABBITIZER_REG_RSP_COP2_CONTROL_31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_RspVector_Descriptors[] = {
    [RABBITIZER_REG_RSP_VECTOR_v0] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v1] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v2] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v3] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v4] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v5] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v6] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v7] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v8] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v9] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v10] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v11] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v12] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v13] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v14] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v15] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v16] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v17] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v18] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v19] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v20] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v21] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v22] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v23] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v24] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v25] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v26] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v27] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v28] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v29] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v30] = { 0 },
    [RABBITIZER_REG_RSP_VECTOR_v31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R5900VF_Descriptors[] = {
    [RABBITIZER_REG_R5900_VF_vf0] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf1] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf2] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf3] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf4] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf5] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf6] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf7] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf8] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf9] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf10] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf11] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf12] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf13] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf14] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf15] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf16] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf17] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf18] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf19] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf20] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf21] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf22] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf23] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf24] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf25] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf26] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf27] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf28] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf29] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf30] = { 0 },
    [RABBITIZER_REG_R5900_VF_vf31] = { 0 },
};
const RabbitizerRegisterDescriptor RabbitizerRegister_R5900VI_Descriptors[] = {
    [RABBITIZER_REG_R5900_VI_vi0] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi1] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi2] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi3] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi4] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi5] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi6] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi7] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi8] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi9] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi10] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi11] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi12] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi13] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi14] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi15] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi16] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi17] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi18] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi19] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi20] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi21] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi22] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi23] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi24] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi25] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi26] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi27] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi28] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi29] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi30] = { 0 },
    [RABBITIZER_REG_R5900_VI_vi31] = { 0 },
};

#endif
