/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

RAB_DEF_OPERAND(r5900, I)
RAB_DEF_OPERAND(r5900, Q)
RAB_DEF_OPERAND(r5900, R)
RAB_DEF_OPERAND(r5900, ACC)
RAB_DEF_OPERAND(r5900, ACCxyzw)
RAB_DEF_OPERAND(r5900, vfs)
RAB_DEF_OPERAND(r5900, vft)
RAB_DEF_OPERAND(r5900, vfd)
RAB_DEF_OPERAND(r5900, vfsxyzw)
RAB_DEF_OPERAND(r5900, vftxyzw)
RAB_DEF_OPERAND(r5900, vfdxyzw)
RAB_DEF_OPERAND(r5900, vfsn)
RAB_DEF_OPERAND(r5900, vftn)
RAB_DEF_OPERAND(r5900, vfdn)
RAB_DEF_OPERAND(r5900, vfsl)
RAB_DEF_OPERAND(r5900, vftl)
RAB_DEF_OPERAND(r5900, vfdl)
RAB_DEF_OPERAND(r5900, vfsm)
RAB_DEF_OPERAND(r5900, vftm)
RAB_DEF_OPERAND(r5900, vfdm)
RAB_DEF_OPERAND(r5900, vis)
RAB_DEF_OPERAND(r5900, vit)
RAB_DEF_OPERAND(r5900, vid)
RAB_DEF_OPERAND(r5900, vis_predecr)
RAB_DEF_OPERAND(r5900, vit_predecr)
RAB_DEF_OPERAND(r5900, vid_predecr)
RAB_DEF_OPERAND(r5900, vis_postincr)
RAB_DEF_OPERAND(r5900, vit_postincr)
RAB_DEF_OPERAND(r5900, vid_postincr)
RAB_DEF_OPERAND(r5900, immediate5)
