/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

/* Automatically generated. DO NOT MODIFY */

#ifndef Registers_enums_table_h_automatic
#define Registers_enums_table_h_automatic

typedef enum RabbitizerRegister_GprO32 {
    RABBITIZER_REG_GPR_O32_zero,
    RABBITIZER_REG_GPR_O32_at,
    RABBITIZER_REG_GPR_O32_v0,
    RABBITIZER_REG_GPR_O32_v1,
    RABBITIZER_REG_GPR_O32_a0,
    RABBITIZER_REG_GPR_O32_a1,
    RABBITIZER_REG_GPR_O32_a2,
    RABBITIZER_REG_GPR_O32_a3,
    RABBITIZER_REG_GPR_O32_t0,
    RABBITIZER_REG_GPR_O32_t1,
    RABBITIZER_REG_GPR_O32_t2,
    RABBITIZER_REG_GPR_O32_t3,
    RABBITIZER_REG_GPR_O32_t4,
    RABBITIZER_REG_GPR_O32_t5,
    RABBITIZER_REG_GPR_O32_t6,
    RABBITIZER_REG_GPR_O32_t7,
    RABBITIZER_REG_GPR_O32_s0,
    RABBITIZER_REG_GPR_O32_s1,
    RABBITIZER_REG_GPR_O32_s2,
    RABBITIZER_REG_GPR_O32_s3,
    RABBITIZER_REG_GPR_O32_s4,
    RABBITIZER_REG_GPR_O32_s5,
    RABBITIZER_REG_GPR_O32_s6,
    RABBITIZER_REG_GPR_O32_s7,
    RABBITIZER_REG_GPR_O32_t8,
    RABBITIZER_REG_GPR_O32_t9,
    RABBITIZER_REG_GPR_O32_k0,
    RABBITIZER_REG_GPR_O32_k1,
    RABBITIZER_REG_GPR_O32_gp,
    RABBITIZER_REG_GPR_O32_sp,
    RABBITIZER_REG_GPR_O32_fp,
    RABBITIZER_REG_GPR_O32_ra,
} RabbitizerRegister_GprO32;
typedef enum RabbitizerRegister_GprN32 {
    RABBITIZER_REG_GPR_N32_zero,
    RABBITIZER_REG_GPR_N32_at,
    RABBITIZER_REG_GPR_N32_v0,
    RABBITIZER_REG_GPR_N32_v1,
    RABBITIZER_REG_GPR_N32_a0,
    RABBITIZER_REG_GPR_N32_a1,
    RABBITIZER_REG_GPR_N32_a2,
    RABBITIZER_REG_GPR_N32_a3,
    RABBITIZER_REG_GPR_N32_a4,
    RABBITIZER_REG_GPR_N32_a5,
    RABBITIZER_REG_GPR_N32_a6,
    RABBITIZER_REG_GPR_N32_a7,
    RABBITIZER_REG_GPR_N32_t0,
    RABBITIZER_REG_GPR_N32_t1,
    RABBITIZER_REG_GPR_N32_t2,
    RABBITIZER_REG_GPR_N32_t3,
    RABBITIZER_REG_GPR_N32_s0,
    RABBITIZER_REG_GPR_N32_s1,
    RABBITIZER_REG_GPR_N32_s2,
    RABBITIZER_REG_GPR_N32_s3,
    RABBITIZER_REG_GPR_N32_s4,
    RABBITIZER_REG_GPR_N32_s5,
    RABBITIZER_REG_GPR_N32_s6,
    RABBITIZER_REG_GPR_N32_s7,
    RABBITIZER_REG_GPR_N32_t8,
    RABBITIZER_REG_GPR_N32_t9,
    RABBITIZER_REG_GPR_N32_k0,
    RABBITIZER_REG_GPR_N32_k1,
    RABBITIZER_REG_GPR_N32_gp,
    RABBITIZER_REG_GPR_N32_sp,
    RABBITIZER_REG_GPR_N32_fp,
    RABBITIZER_REG_GPR_N32_ra,
} RabbitizerRegister_GprN32;
typedef enum RabbitizerRegister_Cop0 {
    RABBITIZER_REG_COP0_Index,
    RABBITIZER_REG_COP0_Random,
    RABBITIZER_REG_COP0_EntryLo0,
    RABBITIZER_REG_COP0_EntryLo1,
    RABBITIZER_REG_COP0_Context,
    RABBITIZER_REG_COP0_PageMask,
    RABBITIZER_REG_COP0_Wired,
    RABBITIZER_REG_COP0_Reserved07,
    RABBITIZER_REG_COP0_BadVaddr,
    RABBITIZER_REG_COP0_Count,
    RABBITIZER_REG_COP0_EntryHi,
    RABBITIZER_REG_COP0_Compare,
    RABBITIZER_REG_COP0_Status,
    RABBITIZER_REG_COP0_Cause,
    RABBITIZER_REG_COP0_EPC,
    RABBITIZER_REG_COP0_PRevID,
    RABBITIZER_REG_COP0_Config,
    RABBITIZER_REG_COP0_LLAddr,
    RABBITIZER_REG_COP0_WatchLo,
    RABBITIZER_REG_COP0_WatchHi,
    RABBITIZER_REG_COP0_XContext,
    RABBITIZER_REG_COP0_Reserved21,
    RABBITIZER_REG_COP0_Reserved22,
    RABBITIZER_REG_COP0_Reserved23,
    RABBITIZER_REG_COP0_Reserved24,
    RABBITIZER_REG_COP0_Reserved25,
    RABBITIZER_REG_COP0_PErr,
    RABBITIZER_REG_COP0_CacheErr,
    RABBITIZER_REG_COP0_TagLo,
    RABBITIZER_REG_COP0_TagHi,
    RABBITIZER_REG_COP0_ErrorEPC,
    RABBITIZER_REG_COP0_Reserved31,
} RabbitizerRegister_Cop0;
typedef enum RabbitizerRegister_Cop1O32 {
    RABBITIZER_REG_COP1_O32_fv0,
    RABBITIZER_REG_COP1_O32_fv0f,
    RABBITIZER_REG_COP1_O32_fv1,
    RABBITIZER_REG_COP1_O32_fv1f,
    RABBITIZER_REG_COP1_O32_ft0,
    RABBITIZER_REG_COP1_O32_ft0f,
    RABBITIZER_REG_COP1_O32_ft1,
    RABBITIZER_REG_COP1_O32_ft1f,
    RABBITIZER_REG_COP1_O32_ft2,
    RABBITIZER_REG_COP1_O32_ft2f,
    RABBITIZER_REG_COP1_O32_ft3,
    RABBITIZER_REG_COP1_O32_ft3f,
    RABBITIZER_REG_COP1_O32_fa0,
    RABBITIZER_REG_COP1_O32_fa0f,
    RABBITIZER_REG_COP1_O32_fa1,
    RABBITIZER_REG_COP1_O32_fa1f,
    RABBITIZER_REG_COP1_O32_ft4,
    RABBITIZER_REG_COP1_O32_ft4f,
    RABBITIZER_REG_COP1_O32_ft5,
    RABBITIZER_REG_COP1_O32_ft5f,
    RABBITIZER_REG_COP1_O32_fs0,
    RABBITIZER_REG_COP1_O32_fs0f,
    RABBITIZER_REG_COP1_O32_fs1,
    RABBITIZER_REG_COP1_O32_fs1f,
    RABBITIZER_REG_COP1_O32_fs2,
    RABBITIZER_REG_COP1_O32_fs2f,
    RABBITIZER_REG_COP1_O32_fs3,
    RABBITIZER_REG_COP1_O32_fs3f,
    RABBITIZER_REG_COP1_O32_fs4,
    RABBITIZER_REG_COP1_O32_fs4f,
    RABBITIZER_REG_COP1_O32_fs5,
    RABBITIZER_REG_COP1_O32_fs5f,
} RabbitizerRegister_Cop1O32;
typedef enum RabbitizerRegister_Cop1N32 {
    RABBITIZER_REG_COP1_N32_fv0,
    RABBITIZER_REG_COP1_N32_ft14,
    RABBITIZER_REG_COP1_N32_fv1,
    RABBITIZER_REG_COP1_N32_ft15,
    RABBITIZER_REG_COP1_N32_ft0,
    RABBITIZER_REG_COP1_N32_ft1,
    RABBITIZER_REG_COP1_N32_ft2,
    RABBITIZER_REG_COP1_N32_ft3,
    RABBITIZER_REG_COP1_N32_ft4,
    RABBITIZER_REG_COP1_N32_ft5,
    RABBITIZER_REG_COP1_N32_ft6,
    RABBITIZER_REG_COP1_N32_ft7,
    RABBITIZER_REG_COP1_N32_fa0,
    RABBITIZER_REG_COP1_N32_fa1,
    RABBITIZER_REG_COP1_N32_fa2,
    RABBITIZER_REG_COP1_N32_fa3,
    RABBITIZER_REG_COP1_N32_fa4,
    RABBITIZER_REG_COP1_N32_fa5,
    RABBITIZER_REG_COP1_N32_fa6,
    RABBITIZER_REG_COP1_N32_fa7,
    RABBITIZER_REG_COP1_N32_fs0,
    RABBITIZER_REG_COP1_N32_ft8,
    RABBITIZER_REG_COP1_N32_fs1,
    RABBITIZER_REG_COP1_N32_ft9,
    RABBITIZER_REG_COP1_N32_fs2,
    RABBITIZER_REG_COP1_N32_ft10,
    RABBITIZER_REG_COP1_N32_fs3,
    RABBITIZER_REG_COP1_N32_ft11,
    RABBITIZER_REG_COP1_N32_fs4,
    RABBITIZER_REG_COP1_N32_ft12,
    RABBITIZER_REG_COP1_N32_fs5,
    RABBITIZER_REG_COP1_N32_ft13,
} RabbitizerRegister_Cop1N32;
typedef enum RabbitizerRegister_Cop1N64 {
    RABBITIZER_REG_COP1_N64_fv0,
    RABBITIZER_REG_COP1_N64_ft12,
    RABBITIZER_REG_COP1_N64_fv1,
    RABBITIZER_REG_COP1_N64_ft13,
    RABBITIZER_REG_COP1_N64_ft0,
    RABBITIZER_REG_COP1_N64_ft1,
    RABBITIZER_REG_COP1_N64_ft2,
    RABBITIZER_REG_COP1_N64_ft3,
    RABBITIZER_REG_COP1_N64_ft4,
    RABBITIZER_REG_COP1_N64_ft5,
    RABBITIZER_REG_COP1_N64_ft6,
    RABBITIZER_REG_COP1_N64_ft7,
    RABBITIZER_REG_COP1_N64_fa0,
    RABBITIZER_REG_COP1_N64_fa1,
    RABBITIZER_REG_COP1_N64_fa2,
    RABBITIZER_REG_COP1_N64_fa3,
    RABBITIZER_REG_COP1_N64_fa4,
    RABBITIZER_REG_COP1_N64_fa5,
    RABBITIZER_REG_COP1_N64_fa6,
    RABBITIZER_REG_COP1_N64_fa7,
    RABBITIZER_REG_COP1_N64_ft8,
    RABBITIZER_REG_COP1_N64_ft9,
    RABBITIZER_REG_COP1_N64_ft10,
    RABBITIZER_REG_COP1_N64_ft11,
    RABBITIZER_REG_COP1_N64_fs0,
    RABBITIZER_REG_COP1_N64_fs1,
    RABBITIZER_REG_COP1_N64_fs2,
    RABBITIZER_REG_COP1_N64_fs3,
    RABBITIZER_REG_COP1_N64_fs4,
    RABBITIZER_REG_COP1_N64_fs5,
    RABBITIZER_REG_COP1_N64_fs6,
    RABBITIZER_REG_COP1_N64_fs7,
} RabbitizerRegister_Cop1N64;
typedef enum RabbitizerRegister_Cop1Control {
    RABBITIZER_REG_COP1_CONTROL_0,
    RABBITIZER_REG_COP1_CONTROL_1,
    RABBITIZER_REG_COP1_CONTROL_2,
    RABBITIZER_REG_COP1_CONTROL_3,
    RABBITIZER_REG_COP1_CONTROL_4,
    RABBITIZER_REG_COP1_CONTROL_5,
    RABBITIZER_REG_COP1_CONTROL_6,
    RABBITIZER_REG_COP1_CONTROL_7,
    RABBITIZER_REG_COP1_CONTROL_8,
    RABBITIZER_REG_COP1_CONTROL_9,
    RABBITIZER_REG_COP1_CONTROL_10,
    RABBITIZER_REG_COP1_CONTROL_11,
    RABBITIZER_REG_COP1_CONTROL_12,
    RABBITIZER_REG_COP1_CONTROL_13,
    RABBITIZER_REG_COP1_CONTROL_14,
    RABBITIZER_REG_COP1_CONTROL_15,
    RABBITIZER_REG_COP1_CONTROL_16,
    RABBITIZER_REG_COP1_CONTROL_17,
    RABBITIZER_REG_COP1_CONTROL_18,
    RABBITIZER_REG_COP1_CONTROL_19,
    RABBITIZER_REG_COP1_CONTROL_20,
    RABBITIZER_REG_COP1_CONTROL_21,
    RABBITIZER_REG_COP1_CONTROL_22,
    RABBITIZER_REG_COP1_CONTROL_23,
    RABBITIZER_REG_COP1_CONTROL_24,
    RABBITIZER_REG_COP1_CONTROL_25,
    RABBITIZER_REG_COP1_CONTROL_26,
    RABBITIZER_REG_COP1_CONTROL_27,
    RABBITIZER_REG_COP1_CONTROL_28,
    RABBITIZER_REG_COP1_CONTROL_29,
    RABBITIZER_REG_COP1_CONTROL_30,
    RABBITIZER_REG_COP1_CONTROL_FpcCsr,
} RabbitizerRegister_Cop1Control;
typedef enum RabbitizerRegister_Cop2 {
    RABBITIZER_REG_COP2_0,
    RABBITIZER_REG_COP2_1,
    RABBITIZER_REG_COP2_2,
    RABBITIZER_REG_COP2_3,
    RABBITIZER_REG_COP2_4,
    RABBITIZER_REG_COP2_5,
    RABBITIZER_REG_COP2_6,
    RABBITIZER_REG_COP2_7,
    RABBITIZER_REG_COP2_8,
    RABBITIZER_REG_COP2_9,
    RABBITIZER_REG_COP2_10,
    RABBITIZER_REG_COP2_11,
    RABBITIZER_REG_COP2_12,
    RABBITIZER_REG_COP2_13,
    RABBITIZER_REG_COP2_14,
    RABBITIZER_REG_COP2_15,
    RABBITIZER_REG_COP2_16,
    RABBITIZER_REG_COP2_17,
    RABBITIZER_REG_COP2_18,
    RABBITIZER_REG_COP2_19,
    RABBITIZER_REG_COP2_20,
    RABBITIZER_REG_COP2_21,
    RABBITIZER_REG_COP2_22,
    RABBITIZER_REG_COP2_23,
    RABBITIZER_REG_COP2_24,
    RABBITIZER_REG_COP2_25,
    RABBITIZER_REG_COP2_26,
    RABBITIZER_REG_COP2_27,
    RABBITIZER_REG_COP2_28,
    RABBITIZER_REG_COP2_29,
    RABBITIZER_REG_COP2_30,
    RABBITIZER_REG_COP2_31,
} RabbitizerRegister_Cop2;
typedef enum RabbitizerRegister_RspGpr {
    RABBITIZER_REG_RSP_GPR_zero,
    RABBITIZER_REG_RSP_GPR_1,
    RABBITIZER_REG_RSP_GPR_2,
    RABBITIZER_REG_RSP_GPR_3,
    RABBITIZER_REG_RSP_GPR_4,
    RABBITIZER_REG_RSP_GPR_5,
    RABBITIZER_REG_RSP_GPR_6,
    RABBITIZER_REG_RSP_GPR_7,
    RABBITIZER_REG_RSP_GPR_8,
    RABBITIZER_REG_RSP_GPR_9,
    RABBITIZER_REG_RSP_GPR_10,
    RABBITIZER_REG_RSP_GPR_11,
    RABBITIZER_REG_RSP_GPR_12,
    RABBITIZER_REG_RSP_GPR_13,
    RABBITIZER_REG_RSP_GPR_14,
    RABBITIZER_REG_RSP_GPR_15,
    RABBITIZER_REG_RSP_GPR_16,
    RABBITIZER_REG_RSP_GPR_17,
    RABBITIZER_REG_RSP_GPR_18,
    RABBITIZER_REG_RSP_GPR_19,
    RABBITIZER_REG_RSP_GPR_20,
    RABBITIZER_REG_RSP_GPR_21,
    RABBITIZER_REG_RSP_GPR_22,
    RABBITIZER_REG_RSP_GPR_23,
    RABBITIZER_REG_RSP_GPR_24,
    RABBITIZER_REG_RSP_GPR_25,
    RABBITIZER_REG_RSP_GPR_26,
    RABBITIZER_REG_RSP_GPR_27,
    RABBITIZER_REG_RSP_GPR_28,
    RABBITIZER_REG_RSP_GPR_29,
    RABBITIZER_REG_RSP_GPR_30,
    RABBITIZER_REG_RSP_GPR_ra,
} RabbitizerRegister_RspGpr;
typedef enum RabbitizerRegister_RspCop0 {
    RABBITIZER_REG_RSP_COP0_SP_MEM_ADDR,
    RABBITIZER_REG_RSP_COP0_SP_DRAM_ADDR,
    RABBITIZER_REG_RSP_COP0_SP_RD_LEN,
    RABBITIZER_REG_RSP_COP0_SP_WR_LEN,
    RABBITIZER_REG_RSP_COP0_SP_STATUS,
    RABBITIZER_REG_RSP_COP0_SP_DMA_FULL,
    RABBITIZER_REG_RSP_COP0_SP_DMA_BUSY,
    RABBITIZER_REG_RSP_COP0_SP_SEMAPHORE,
    RABBITIZER_REG_RSP_COP0_DPC_START,
    RABBITIZER_REG_RSP_COP0_DPC_END,
    RABBITIZER_REG_RSP_COP0_DPC_CURRENT,
    RABBITIZER_REG_RSP_COP0_DPC_STATUS,
    RABBITIZER_REG_RSP_COP0_DPC_CLOCK,
    RABBITIZER_REG_RSP_COP0_DPC_BUFBUSY,
    RABBITIZER_REG_RSP_COP0_DPC_PIPEBUSY,
    RABBITIZER_REG_RSP_COP0_DPC_TMEM,
} RabbitizerRegister_RspCop0;
typedef enum RabbitizerRegister_RspCop2 {
    RABBITIZER_REG_RSP_COP2_0,
    RABBITIZER_REG_RSP_COP2_1,
    RABBITIZER_REG_RSP_COP2_2,
    RABBITIZER_REG_RSP_COP2_3,
    RABBITIZER_REG_RSP_COP2_4,
    RABBITIZER_REG_RSP_COP2_5,
    RABBITIZER_REG_RSP_COP2_6,
    RABBITIZER_REG_RSP_COP2_7,
    RABBITIZER_REG_RSP_COP2_8,
    RABBITIZER_REG_RSP_COP2_9,
    RABBITIZER_REG_RSP_COP2_10,
    RABBITIZER_REG_RSP_COP2_11,
    RABBITIZER_REG_RSP_COP2_12,
    RABBITIZER_REG_RSP_COP2_13,
    RABBITIZER_REG_RSP_COP2_14,
    RABBITIZER_REG_RSP_COP2_15,
    RABBITIZER_REG_RSP_COP2_16,
    RABBITIZER_REG_RSP_COP2_17,
    RABBITIZER_REG_RSP_COP2_18,
    RABBITIZER_REG_RSP_COP2_19,
    RABBITIZER_REG_RSP_COP2_20,
    RABBITIZER_REG_RSP_COP2_21,
    RABBITIZER_REG_RSP_COP2_22,
    RABBITIZER_REG_RSP_COP2_23,
    RABBITIZER_REG_RSP_COP2_24,
    RABBITIZER_REG_RSP_COP2_25,
    RABBITIZER_REG_RSP_COP2_26,
    RABBITIZER_REG_RSP_COP2_27,
    RABBITIZER_REG_RSP_COP2_28,
    RABBITIZER_REG_RSP_COP2_29,
    RABBITIZER_REG_RSP_COP2_30,
    RABBITIZER_REG_RSP_COP2_31,
} RabbitizerRegister_RspCop2;
typedef enum RabbitizerRegister_RspCop2Control {
    RABBITIZER_REG_RSP_COP2_CONTROL_0,
    RABBITIZER_REG_RSP_COP2_CONTROL_1,
    RABBITIZER_REG_RSP_COP2_CONTROL_2,
    RABBITIZER_REG_RSP_COP2_CONTROL_3,
    RABBITIZER_REG_RSP_COP2_CONTROL_4,
    RABBITIZER_REG_RSP_COP2_CONTROL_5,
    RABBITIZER_REG_RSP_COP2_CONTROL_6,
    RABBITIZER_REG_RSP_COP2_CONTROL_7,
    RABBITIZER_REG_RSP_COP2_CONTROL_8,
    RABBITIZER_REG_RSP_COP2_CONTROL_9,
    RABBITIZER_REG_RSP_COP2_CONTROL_10,
    RABBITIZER_REG_RSP_COP2_CONTROL_11,
    RABBITIZER_REG_RSP_COP2_CONTROL_12,
    RABBITIZER_REG_RSP_COP2_CONTROL_13,
    RABBITIZER_REG_RSP_COP2_CONTROL_14,
    RABBITIZER_REG_RSP_COP2_CONTROL_15,
    RABBITIZER_REG_RSP_COP2_CONTROL_16,
    RABBITIZER_REG_RSP_COP2_CONTROL_17,
    RABBITIZER_REG_RSP_COP2_CONTROL_18,
    RABBITIZER_REG_RSP_COP2_CONTROL_19,
    RABBITIZER_REG_RSP_COP2_CONTROL_20,
    RABBITIZER_REG_RSP_COP2_CONTROL_21,
    RABBITIZER_REG_RSP_COP2_CONTROL_22,
    RABBITIZER_REG_RSP_COP2_CONTROL_23,
    RABBITIZER_REG_RSP_COP2_CONTROL_24,
    RABBITIZER_REG_RSP_COP2_CONTROL_25,
    RABBITIZER_REG_RSP_COP2_CONTROL_26,
    RABBITIZER_REG_RSP_COP2_CONTROL_27,
    RABBITIZER_REG_RSP_COP2_CONTROL_28,
    RABBITIZER_REG_RSP_COP2_CONTROL_29,
    RABBITIZER_REG_RSP_COP2_CONTROL_30,
    RABBITIZER_REG_RSP_COP2_CONTROL_31,
} RabbitizerRegister_RspCop2Control;
typedef enum RabbitizerRegister_RspVector {
    RABBITIZER_REG_RSP_VECTOR_v0,
    RABBITIZER_REG_RSP_VECTOR_v1,
    RABBITIZER_REG_RSP_VECTOR_v2,
    RABBITIZER_REG_RSP_VECTOR_v3,
    RABBITIZER_REG_RSP_VECTOR_v4,
    RABBITIZER_REG_RSP_VECTOR_v5,
    RABBITIZER_REG_RSP_VECTOR_v6,
    RABBITIZER_REG_RSP_VECTOR_v7,
    RABBITIZER_REG_RSP_VECTOR_v8,
    RABBITIZER_REG_RSP_VECTOR_v9,
    RABBITIZER_REG_RSP_VECTOR_v10,
    RABBITIZER_REG_RSP_VECTOR_v11,
    RABBITIZER_REG_RSP_VECTOR_v12,
    RABBITIZER_REG_RSP_VECTOR_v13,
    RABBITIZER_REG_RSP_VECTOR_v14,
    RABBITIZER_REG_RSP_VECTOR_v15,
    RABBITIZER_REG_RSP_VECTOR_v16,
    RABBITIZER_REG_RSP_VECTOR_v17,
    RABBITIZER_REG_RSP_VECTOR_v18,
    RABBITIZER_REG_RSP_VECTOR_v19,
    RABBITIZER_REG_RSP_VECTOR_v20,
    RABBITIZER_REG_RSP_VECTOR_v21,
    RABBITIZER_REG_RSP_VECTOR_v22,
    RABBITIZER_REG_RSP_VECTOR_v23,
    RABBITIZER_REG_RSP_VECTOR_v24,
    RABBITIZER_REG_RSP_VECTOR_v25,
    RABBITIZER_REG_RSP_VECTOR_v26,
    RABBITIZER_REG_RSP_VECTOR_v27,
    RABBITIZER_REG_RSP_VECTOR_v28,
    RABBITIZER_REG_RSP_VECTOR_v29,
    RABBITIZER_REG_RSP_VECTOR_v30,
    RABBITIZER_REG_RSP_VECTOR_v31,
} RabbitizerRegister_RspVector;
typedef enum RabbitizerRegister_R5900VF {
    RABBITIZER_REG_R5900_VF_vf0,
    RABBITIZER_REG_R5900_VF_vf1,
    RABBITIZER_REG_R5900_VF_vf2,
    RABBITIZER_REG_R5900_VF_vf3,
    RABBITIZER_REG_R5900_VF_vf4,
    RABBITIZER_REG_R5900_VF_vf5,
    RABBITIZER_REG_R5900_VF_vf6,
    RABBITIZER_REG_R5900_VF_vf7,
    RABBITIZER_REG_R5900_VF_vf8,
    RABBITIZER_REG_R5900_VF_vf9,
    RABBITIZER_REG_R5900_VF_vf10,
    RABBITIZER_REG_R5900_VF_vf11,
    RABBITIZER_REG_R5900_VF_vf12,
    RABBITIZER_REG_R5900_VF_vf13,
    RABBITIZER_REG_R5900_VF_vf14,
    RABBITIZER_REG_R5900_VF_vf15,
    RABBITIZER_REG_R5900_VF_vf16,
    RABBITIZER_REG_R5900_VF_vf17,
    RABBITIZER_REG_R5900_VF_vf18,
    RABBITIZER_REG_R5900_VF_vf19,
    RABBITIZER_REG_R5900_VF_vf20,
    RABBITIZER_REG_R5900_VF_vf21,
    RABBITIZER_REG_R5900_VF_vf22,
    RABBITIZER_REG_R5900_VF_vf23,
    RABBITIZER_REG_R5900_VF_vf24,
    RABBITIZER_REG_R5900_VF_vf25,
    RABBITIZER_REG_R5900_VF_vf26,
    RABBITIZER_REG_R5900_VF_vf27,
    RABBITIZER_REG_R5900_VF_vf28,
    RABBITIZER_REG_R5900_VF_vf29,
    RABBITIZER_REG_R5900_VF_vf30,
    RABBITIZER_REG_R5900_VF_vf31,
} RabbitizerRegister_R5900VF;
typedef enum RabbitizerRegister_R5900VI {
    RABBITIZER_REG_R5900_VI_vi0,
    RABBITIZER_REG_R5900_VI_vi1,
    RABBITIZER_REG_R5900_VI_vi2,
    RABBITIZER_REG_R5900_VI_vi3,
    RABBITIZER_REG_R5900_VI_vi4,
    RABBITIZER_REG_R5900_VI_vi5,
    RABBITIZER_REG_R5900_VI_vi6,
    RABBITIZER_REG_R5900_VI_vi7,
    RABBITIZER_REG_R5900_VI_vi8,
    RABBITIZER_REG_R5900_VI_vi9,
    RABBITIZER_REG_R5900_VI_vi10,
    RABBITIZER_REG_R5900_VI_vi11,
    RABBITIZER_REG_R5900_VI_vi12,
    RABBITIZER_REG_R5900_VI_vi13,
    RABBITIZER_REG_R5900_VI_vi14,
    RABBITIZER_REG_R5900_VI_vi15,
    RABBITIZER_REG_R5900_VI_vi16,
    RABBITIZER_REG_R5900_VI_vi17,
    RABBITIZER_REG_R5900_VI_vi18,
    RABBITIZER_REG_R5900_VI_vi19,
    RABBITIZER_REG_R5900_VI_vi20,
    RABBITIZER_REG_R5900_VI_vi21,
    RABBITIZER_REG_R5900_VI_vi22,
    RABBITIZER_REG_R5900_VI_vi23,
    RABBITIZER_REG_R5900_VI_vi24,
    RABBITIZER_REG_R5900_VI_vi25,
    RABBITIZER_REG_R5900_VI_vi26,
    RABBITIZER_REG_R5900_VI_vi27,
    RABBITIZER_REG_R5900_VI_vi28,
    RABBITIZER_REG_R5900_VI_vi29,
    RABBITIZER_REG_R5900_VI_vi30,
    RABBITIZER_REG_R5900_VI_vi31,
} RabbitizerRegister_R5900VI;

#endif
