/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG(
        RSP_VECTOR, v0,   0,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v1,   1,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v2,   2,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v3,   3,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v4,   4,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v5,   5,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v6,   6,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v7,   7,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v8,   8,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v9,   9,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v10, 10,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v11, 11,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v12, 12,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v13, 13,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v14, 14,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v15, 15,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v16, 16,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v17, 17,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v18, 18,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v19, 19,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v20, 20,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v21, 21,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v22, 22,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v23, 23,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v24, 24,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v25, 25,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v26, 26,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v27, 27,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v28, 28,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v29, 29,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v30, 30,
        0
    )
    RABBITIZER_DEF_REG(
        RSP_VECTOR, v31, 31,
        0
    )
