/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

// OP vt[elementlow], offset(vs)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x00, lbv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x01, lsv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x02, llv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x03, ldv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x04, lqv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x05, lrv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x06, lpv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x07, luv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x08, lhv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x09, lfv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
RABBITIZER_DEF_INSTR_ID(
    rsp, 0x0B, ltv,
    .operands={RAB_OPERAND_rsp_vt_elementlow, RAB_OPERAND_rsp_offset_rs},
    .readsRs=true
)
