/* SPDX-FileCopyrightText: © 2022 Decompollaborate */
/* SPDX-License-Identifier: MIT */

    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Index,       0,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Random,      1,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, EntryLo0,    2,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, EntryLo1,    3,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Context,     4,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, PageMask,    5,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Wired,       6,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved07,  7,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, BadVaddr,    8,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Count,       9,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, EntryHi,    10,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Compare,    11,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Status,     12,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Cause,      13,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, EPC,        14,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, PRevID,     15,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Config,     16,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, LLAddr,     17,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, WatchLo,    18,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, WatchHi,    19,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, XContext,   20,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved21, 21,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved22, 22,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved23, 23,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved24, 24,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved25, 25,
        .isReserved=true
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, PErr,       26,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, CacheErr,   27,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, TagLo,      28,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, TagHi,      29,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, ErrorEPC,   30,
        0
    )
    RABBITIZER_DEF_REG_NODOLLAR(
        COP0, Reserved31, 31,
        .isReserved=true
    )
